@@ -6,7 +6,7 @@ use Stenciller::Wrap;
 
 package Stenciller;
 
-our $VERSION = '0.1212'; # VERSION:
+our $VERSION = '0.1300'; # VERSION:
 # PODCLASSNAME:
 # ABSTRACT: Transforms a flat file format to different output
 
@@ -30,9 +30,24 @@ __END__
 
 Stenciller - Transforms a flat file format to different output
 
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.14+-brightgreen.svg" alt="Requires Perl 5.14+" /> <a href="https://travis-ci.org/Csson/p5-Stenciller"><img src="https://api.travis-ci.org/Csson/p5-Stenciller.svg?branch=master" alt="Travis status" /></a></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.14+](https://img.shields.io/badge/perl-5.14+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Stenciller.svg?branch=master)](https://travis-ci.org/Csson/p5-Stenciller)
+
+=end markdown
+
 =head1 VERSION
 
-Version 0.1212, released 2015-02-10.
+Version 0.1300, released 2015-11-22.
 
 
 
@@ -255,7 +270,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2015 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
