@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 package Stenciller::Plugin::ToUnparsedText;
-our $VERSION = '0.1212'; # VERSION:
+our $VERSION = '0.1300'; # VERSION:
 # ABSTRACT: A plugin that doesn't transform the text
 
 use Moose;
@@ -31,7 +31,7 @@ sub transform {
                      $stencil->all_after_output, '';
     }
     my $content = join "\n" => '', @out, '';
-    $content =~ s{[\r?\n]{2,}}{\n\n}g;
+    $content =~ s{\v{2,}}{\n\n}g;
     return $content;
 }
 
@@ -49,7 +49,7 @@ Stenciller::Plugin::ToUnparsedText - A plugin that doesn't transform the text
 
 =head1 VERSION
 
-Version 0.1212, released 2015-02-10.
+Version 0.1300, released 2015-11-22.
 
 
 
@@ -99,7 +99,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2015 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
