@@ -1,11 +1,14 @@
 use Stenciller::Standard;
+use strict;
+use warnings;
 
-our $VERSION = '0.1212'; # VERSION:
-# ABSTRACT: One part of a file
 # PODNAME: Stenciller::Stencil
 
 class Stenciller::Stencil using Moose {
 
+    our $VERSION = '0.1300'; # VERSION:
+    # ABSTRACT: One part of a file
+
     my @attrs = qw/before_input input between output after_output/;
 
     my $order = 1;
@@ -15,7 +18,7 @@ class Stenciller::Stencil using Moose {
             isa => ArrayRef[Str],
             default => sub { [] },
             traits => ['Array'],
-            init_arg => undef,
+            #init_arg => undef,
             documentation_order => ++$order,
             documentation => sprintf ('Holds all lines of the %s section.', $attr),
             handles => {
@@ -24,6 +27,7 @@ class Stenciller::Stencil using Moose {
                 "all_$attr"    => 'elements',
                 "map_$attr"    => 'map',
                 "get_$attr"    => 'get',
+                "count_$attr"  => 'count',
             },
         );
     }
@@ -33,12 +37,17 @@ class Stenciller::Stencil using Moose {
         default => 0,
         documentation => 'Should the Stencil not be included in the result?',
     );
-
     has line_number => (
         is => 'ro',
         isa => Int,
         documentation => 'Can be referenced in the output for easier backtracking.',
     );
+    has stencil_name => (
+        is => 'ro',
+        isa => Str,
+        documentation => q{Can be given in the stencil hash with 'name'. Depends on used plugins if it is necessary/useful.},
+        documentation_default => '[filename]_[linenumber]',
+    );
     has extra_settings => (
         is => 'ro',
         isa => HashRef,
@@ -93,14 +102,17 @@ class Stenciller::Stencil using Moose {
     }
 
     method clone_with_loop_value(Str $loop_value) {
-        return Stenciller::Stencil->new(
-            before_input => $self->map_before_input( sub { $_ =~ s{ \[ var \] }{$loop_value}x }),
-                   input => $self->map_input( sub { $_ =~ s{ \[ var \] }{$loop_value}x }),
-                 between => $self->map_between( sub { $_ =~ s{ \[ var \] }{$loop_value}x }),
-                  output => $self->map_output( sub { $_ =~ s{ \[ var \] }{$loop_value}x }),
-                   after => $self->map_after( sub { $_ =~ s{ \[ var \] }{$loop_value}x }),
+        my $clone = Stenciller::Stencil->new(
+            before_input => [$self->map_before_input( sub { $_ =~ s{ \[ var \] }{$loop_value}rx })],
+                   input => [$self->map_input( sub { $_ =~ s{ \[ var \] }{$loop_value}rx })],
+                 between => [$self->map_between( sub { $_ =~ s{ \[ var \] }{$loop_value}rx })],
+                  output => [$self->map_output( sub { $_ =~ s{ \[ var \] }{$loop_value}rx })],
+            after_output => [$self->map_after_output( sub {  $_ =~ s{ \[ var \] }{$loop_value}rx })],
+            stencil_name => $self->stencil_name . "_$loop_value",
             (map { $_ => $self->$_ } qw/line_number extra_settings/)
         );
+
+        return $clone;
     }
 
 }
@@ -119,7 +131,7 @@ Stenciller::Stencil - One part of a file
 
 =head1 VERSION
 
-Version 0.1212, released 2015-02-10.
+Version 0.1300, released 2015-11-22.
 
 
 
@@ -154,7 +166,9 @@ A C<Stencil> is one section of the file format defined in L<Stenciller>.
 
 <table cellpadding="0" cellspacing="0">
 <tr><td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#ArrayRef">ArrayRef</a> [ <a href="https://metacpan.org/pod/Types::Standard#Str">Str</a> ]</td>
-<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">not in constructor</td>
+<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default is a <code>coderef</code>
+
+</td>
 <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td></tr>
 </table>
 
@@ -168,7 +182,9 @@ A C<Stencil> is one section of the file format defined in L<Stenciller>.
 
 <table cellpadding="0" cellspacing="0">
 <tr><td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#ArrayRef">ArrayRef</a> [ <a href="https://metacpan.org/pod/Types::Standard#Str">Str</a> ]</td>
-<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">not in constructor</td>
+<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default is a <code>coderef</code>
+
+</td>
 <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td></tr>
 </table>
 
@@ -182,7 +198,9 @@ A C<Stencil> is one section of the file format defined in L<Stenciller>.
 
 <table cellpadding="0" cellspacing="0">
 <tr><td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#ArrayRef">ArrayRef</a> [ <a href="https://metacpan.org/pod/Types::Standard#Str">Str</a> ]</td>
-<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">not in constructor</td>
+<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default is a <code>coderef</code>
+
+</td>
 <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td></tr>
 </table>
 
@@ -196,7 +214,9 @@ A C<Stencil> is one section of the file format defined in L<Stenciller>.
 
 <table cellpadding="0" cellspacing="0">
 <tr><td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#ArrayRef">ArrayRef</a> [ <a href="https://metacpan.org/pod/Types::Standard#Str">Str</a> ]</td>
-<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">not in constructor</td>
+<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default is a <code>coderef</code>
+
+</td>
 <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td></tr>
 </table>
 
@@ -210,7 +230,9 @@ A C<Stencil> is one section of the file format defined in L<Stenciller>.
 
 <table cellpadding="0" cellspacing="0">
 <tr><td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#ArrayRef">ArrayRef</a> [ <a href="https://metacpan.org/pod/Types::Standard#Str">Str</a> ]</td>
-<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">not in constructor</td>
+<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default is a <code>coderef</code>
+
+</td>
 <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td></tr>
 </table>
 
@@ -270,6 +292,22 @@ A C<Stencil> is one section of the file format defined in L<Stenciller>.
 
 =end HTML
 
+=head2 stencil_name
+
+=begin HTML
+
+<table cellpadding="0" cellspacing="0">
+<tr><td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a>
+
+</td>
+<td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional</td>
+<td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td></tr>
+</table>
+
+<p>Can be given in the stencil hash with 'name'. Depends on used plugins if it is necessary/useful.</p>
+
+=end HTML
+
 =head1 SOURCE
 
 L<https://github.com/Csson/p5-Stenciller>
@@ -284,7 +322,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2015 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
