@@ -1,11 +1,14 @@
 use Stenciller::Standard;
+use strict;
+use warnings;
 
-our $VERSION = '0.1212'; # VERSION:
-# ABSTRACT: A role for transformer plugins to consume
 # PODNAME: Stenciller::Transformer
 
 role Stenciller::Transformer using Moose {
 
+    our $VERSION = '0.1300'; # VERSION:
+    # ABSTRACT: A role for transformer plugins to consume
+
     requires 'transform';
 
     has stenciller => (
@@ -50,7 +53,7 @@ Stenciller::Transformer - A role for transformer plugins to consume
 
 =head1 VERSION
 
-Version 0.1212, released 2015-02-10.
+Version 0.1300, released 2015-11-22.
 
 
 
@@ -143,7 +146,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2015 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
