@@ -1,10 +1,13 @@
 use Stenciller::Standard;
+use strict;
+use warnings;
 
-our $VERSION = '0.1212'; # VERSION:
 # PODNAME: Stenciller::Utils
 
 role Stenciller::Utils using Moose {
 
+    our $VERSION = '0.1300'; # VERSION:
+
     method eval_to_hashref(Str $possible_hash!, Path|Str $faulty_file! --> HashRef) {
         my $settings = eval $possible_hash;
         die sprintf "Can't parse stencil start: <%s> in %s: %s", $possible_hash, $faulty_file, $@ if $@;
@@ -31,7 +34,7 @@ Stenciller::Utils
 
 =head1 VERSION
 
-Version 0.1212, released 2015-02-10.
+Version 0.1300, released 2015-11-22.
 
 =head1 SOURCE
 
@@ -47,7 +50,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2015 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
