@@ -2,7 +2,7 @@ use Stenciller::Standard;
 use Stenciller::Stencil;
 use strict;
 use warnings;
-our $VERSION = '0.1212'; # VERSION:
+our $VERSION = '0.1300'; # VERSION:
 # PODNAME: Stenciller::Wrap
 
 use Module::Pluggable search_path => ['Stenciller::Plugin'];
@@ -125,12 +125,16 @@ class Stenciller::Wrap using Moose with Stenciller::Utils {
                              : {}
                              ;
 
+                my $stencil_name = exists $settings->{'name'} ? delete $settings->{'name'} : $self->filepath->basename(qr/\..*/) . "-$line_count";
+                $stencil_name =~ s{[. -]}{_}g;
+                $stencil_name =~ s{[^a-zA-Z0-9_]}{}g;
+
                 $stencil = Stenciller::Stencil->new(
-                            name => exists $settings->{'name'} ? delete $settings->{'name'} : $self->filepath->basename . "-$line_count",
+                            stencil_name => $stencil_name,
                             loop_values => delete $settings->{'loop'},
                             line_number => $line_count,
                       maybe skip  => delete $settings->{'skip'},
-                    provided scalar keys %{ $settings }, extra_settings => $settings,
+                   provided scalar keys %{ $settings }, extra_settings => $settings,
                 );
                 $environment = 'before_input';
             }
@@ -199,7 +203,7 @@ Stenciller::Wrap
 
 =head1 VERSION
 
-Version 0.1212, released 2015-02-10.
+Version 0.1300, released 2015-11-22.
 
 =head1 SOURCE
 
@@ -215,7 +219,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2015 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
